@@ -1,6 +1,19 @@
+import logging
 import os
 
-from dbnd._core.settings import CoreConfig
+from functools import partial
+
+from dbnd_airflow.tracking.conf_operations import fix_keys, flat_conf
+from dbnd_airflow.tracking.config import TrackingConfig
+from dbnd_airflow.tracking.dbnd_airflow_conf import get_airflow_conf
+from dbnd_airflow.utils import logger
+
+
+def spark_env(key):
+    return "spark.env." + key
+
+
+add_spark_env_fields = partial(fix_keys, spark_env)
 
 
 def _filter_vars(key, bypass_dbnd, bypass_airflow, bypass_rest):
@@ -14,7 +27,6 @@ def _filter_vars(key, bypass_dbnd, bypass_airflow, bypass_rest):
 def dbnd_tracking_env(
     new_vars, bypass_dbnd=True, bypass_airflow=True, bypass_rest=False
 ):
-
     environment = {
         key: os.environ[key]
         for key in os.environ.keys()
@@ -37,68 +49,12 @@ def with_dbnd_tracking_spark_conf(user_dict):
     return user_dict
 
 
-def get_dbnd_tracking_spark_conf_dict(
-    dag_id="{{dag.dag_id}}",
-    task_id="{{task.task_id}}",
-    execution_date="{{ts}}",
-    try_number="{{task_instance._try_number}}",
-):
-    spark_conf = {
-        "spark.env.AIRFLOW_CTX_DAG_ID": dag_id,
-        "spark.env.AIRFLOW_CTX_EXECUTION_DATE": execution_date,
-        "spark.env.AIRFLOW_CTX_TASK_ID": task_id,
-        "spark.env.AIRFLOW_CTX_TRY_NUMBER": try_number,
-    }
-
-    databand_url = _get_databand_url()
-    if databand_url:
-        spark_conf["spark.env.DBND__CORE__DATABAND_URL"] = databand_url
-
-    return spark_conf
+def get_dbnd_tracking_spark_conf_dict(**kwargs):
+    return dict(add_spark_env_fields(get_airflow_conf(**kwargs)))
 
 
-def _get_databand_url():
-    try:
-        return CoreConfig().databand_external_url
-    except Exception:
-        pass
-
-
-def get_dbnd_tracking_spark_conf(
-    dag_id="{{dag.dag_id}}",
-    task_id="{{task.task_id}}",
-    execution_date="{{ts}}",
-    try_number="{{task_instance._try_number}}",
-):
-    """ This functions returns Airflow ids  as spark configuration properties. This is used to associate spark run with airflow dag/task.
-        These properties are
-            spark.env.AIRFLOW_CTX_DAG_ID  -  name of the Airflow DAG to associate a run with
-            spark.env.AIRFLOW_CTX_EXECUTION_DATE - execution_date to associate a run with
-            spark.env.AIRFLOW_CTX_TASK_ID" - name of the Airflow Task to associate a run with
-            spark.env.AIRFLOW_CTX_TRY_NUMBER" - try number of the Airflow Task to associate a run with
-
-        Example:
-            >>> get_dbnd_tracking_spark_conf()
-            ['--conf', 'spark.env.AIRFLOW_CTX_DAG_ID={{dag.dag_id}}', '--conf', 'spark.env.AIRFLOW_CTX_EXECUTION_DATE={{ts}}', '--conf', 'spark.env.AIRFLOW_CTX_TASK_ID={{task.task_id}}', '--conf', 'spark.env.AIRFLOW_CTX_TRY_NUMBER={{task._try_number}}']
-
-        Args:
-            dag_id: name of the Airflow DAG to associate a run. By default set to {{dag.dag_id}} Airflow template
-            task_id: name of the Airflow task to associate a run. By default set to {{task.task_id}} Airflow template
-            execution_date: execution date as a string. By default set to {{ts}} Airflow template
-            try_number: try number of Airflow task. By default set to {{task_instance._try_number}} Airflow template
-
-        Returns:
-            List of Airflow Ids as spark properties. Ready to concatenate to spark-submit command
-
-    """
-
-    conf_as_dict = get_dbnd_tracking_spark_conf_dict(
-        dag_id, task_id, execution_date, try_number
-    )
-    conf = []
-    for key in conf_as_dict.keys():
-        conf.extend(["--conf", key + "=" + conf_as_dict[key]])
-    return conf
+def get_dbnd_tracking_spark_conf(**kwargs):
+    return flat_conf(add_spark_env_fields(get_airflow_conf(**kwargs)))
 
 
 def spark_submit_with_dbnd_tracking(command_as_list, dbnd_context=None):
@@ -139,3 +95,36 @@ def spark_submit_with_dbnd_tracking(command_as_list, dbnd_context=None):
         raise Exception("Failed to find spark-submit in %s" % " ".join(command_as_list))
 
     return command_as_list[0 : index + 1] + dbnd_context + command_as_list[index + 1 :]
+
+
+logger = logging.getLogger(__name__)
+
+
+def get_local_spark_java_agent_conf():
+    config = TrackingConfig()
+    agent_jar = config.local_dbnd_java_agent
+    logger.debug("found agent_jar %s", agent_jar)
+    if agent_jar is None or not os.path.exists(agent_jar):
+        logger.warning("The wanted agents jar doesn't exists: %s", agent_jar)
+        return
+
+    return create_spark_java_agent_conf(agent_jar)
+
+
+def get_databricks_java_agent_conf():
+    config = TrackingConfig()
+    agent_jar = config.databricks_dbnd_java_agent
+    logger.debug("found agent_jar %s", agent_jar)
+    if agent_jar is None:
+        logger.warning("No agent jar found")
+        return
+
+    return create_spark_java_agent_conf(agent_jar)
+
+
+def create_spark_java_agent_conf(agent_jar):
+    return {
+        "spark.driver.extraJavaOptions": "-javaagent:{agent_jar}".format(
+            agent_jar=agent_jar
+        )
+    }
