@@ -8,6 +8,9 @@ from airflow.models import DagBag, DagModel, DagPickle, TaskInstance
 from airflow.utils.db import provide_session
 from packaging import version
 
+from dbnd._core.errors.friendly_error.versioned_dagbag import (
+    failed_to_retrieve_dag_via_dbnd_versioned_dagbag,
+)
 from dbnd._vendor import pendulum
 
 
@@ -44,57 +47,61 @@ class DbndAirflowDagBag(DagBag):
         :param session:
         :return:
         """
-        from flask import has_request_context, request, session as flask_session
+        try:
+            from flask import has_request_context, request, session as flask_session
 
-        # all legacy airflow code works just with dag_id, also, there are some calls that doesn't pass through execution_date
-        if has_request_context():
-            execution_date = execution_date or request.args.get("execution_date")
+            # all legacy airflow code works just with dag_id, also, there are some calls that doesn't pass through execution_date
+            if has_request_context():
+                execution_date = execution_date or request.args.get("execution_date")
 
-            # trick to store last execution date used for the next flask call
-            if execution_date:
-                logger.debug(
-                    "Execution date saved to session: %s, %s", dag_id, execution_date
+                # trick to store last execution date used for the next flask call
+                if execution_date:
+                    logger.debug(
+                        "Execution date saved to session: %s, %s",
+                        dag_id,
+                        execution_date,
+                    )
+                    flask_session["ed_" + dag_id] = execution_date
+                else:
+                    logger.debug("Execution date from previous session: %s", dag_id)
+                    execution_date = flask_session.get("ed_" + dag_id)
+
+                if execution_date and execution_date != "undefined":
+                    # we are going to return most "active" dag
+                    dttm = pendulum.parse(execution_date)
+                    dag = self._get_pickled_dag_from_dagrun(
+                        dag_id=dag_id, execution_date=dttm, session=session
+                    )
+                    if dag:
+                        return dag
+
+            if version.parse(airflow.__version__) < version.parse("1.10.10"):
+                # get_dag function signature changed in airflow 1.10.10, ensure compatibility in parameters
+                # we don't have specific dag/execution date, we are trying to get in-memory version
+                dag = super(DbndAirflowDagBag, self).get_dag(
+                    dag_id, from_file_only=from_file_only
                 )
-                flask_session["ed_" + dag_id] = execution_date
             else:
-                logger.debug("Execution date from previous session: %s", dag_id)
-                execution_date = flask_session.get("ed_" + dag_id)
+                dag = super(DbndAirflowDagBag, self).get_dag(dag_id)
+            if dag:
+                return dag
 
-            if execution_date and execution_date != "undefined":
-                # we are going to return most "active" dag
-                dttm = pendulum.parse(execution_date)
-                dag = self._get_pickled_dag_from_dagrun(
-                    dag_id=dag_id, execution_date=dttm, session=session
+            # let try to find it latest version in DB
+            latest_execution = (
+                session.query(TaskInstance.execution_date)
+                .filter(TaskInstance.task_id == dag_id)
+                .order_by(TaskInstance.execution_date.desc())
+                .first()
+            )
+
+            if latest_execution:
+                return self._get_pickled_dag_from_dagrun(
+                    dag_id=dag_id,
+                    execution_date=latest_execution.execution_date,
+                    session=session,
                 )
-                if dag:
-                    return dag
-
-        if version.parse(airflow.__version__) < version.parse("1.10.10"):
-            # get_dag function signature changed in airflow 1.10.10, ensure compatibility in parameters
-            # we don't have specific dag/execution date, we are trying to get in-memory version
-            dag = super(DbndAirflowDagBag, self).get_dag(
-                dag_id, from_file_only=from_file_only
-            )
-        else:
-            dag = super(DbndAirflowDagBag, self).get_dag(dag_id)
-        if dag:
-            return dag
-
-        # let try to find it latest version in DB
-        latest_execution = (
-            session.query(TaskInstance.execution_date)
-            .filter(TaskInstance.task_id == dag_id)
-            .order_by(TaskInstance.execution_date.desc())
-            .first()
-        )
-
-        if latest_execution:
-            return self._get_pickled_dag_from_dagrun(
-                dag_id=dag_id,
-                execution_date=latest_execution.execution_date,
-                session=session,
-            )
-
+        except Exception as e:
+            raise failed_to_retrieve_dag_via_dbnd_versioned_dagbag(e)
         return None
 
     @provide_session
